@@ -12,7 +12,6 @@
 #include <gdk/gdkx.h>
 #include <glib/gstdio.h>
 #include <locale.h>
-#include <canberra-gtk.h>
 #include <colord.h>
 #include <math.h>
 
@@ -73,6 +72,7 @@ enum {
 	GCM_PROFILES_COLUMN_LAST
 };
 
+#define GCM_VIEWER_APPLICATION_ID		"org.gnome.ColorProfileViewer"
 #define GCM_VIEWER_TREEVIEW_WIDTH		350 /* px */
 #define GCM_VIEWER_MAX_EXAMPLE_IMAGES		4
 
@@ -1625,6 +1625,8 @@ main (int argc, char **argv)
 	}
 	g_option_context_free (context);
 
+	g_set_prgname (GCM_VIEWER_APPLICATION_ID);
+
 	viewer = g_new0 (GcmViewerPrivate, 1);
 	viewer->xid = xid;
 	viewer->profile_id = profile_id;
@@ -1632,7 +1634,7 @@ main (int argc, char **argv)
 	viewer->lang = g_getenv ("LANG");
 
 	/* ensure single instance */
-	viewer->application = gtk_application_new ("org.gnome.ColorManager.Viewer", 0);
+	viewer->application = gtk_application_new (GCM_VIEWER_APPLICATION_ID, 0);
 	g_signal_connect (viewer->application, "startup",
 			  G_CALLBACK (gcm_viewer_startup_cb), viewer);
 	g_signal_connect (viewer->application, "activate",
